==> nomachine-8.4.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXPingMonitor.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXPingMonitor;no warnings;(my $__pingTime=(0x1236+ 100-0x129a));(my $__pongTime
=(0x0641+ 3759-0x14f0));(my $__interval=(0x1e43+ 908-0x21cf));(my $__timeout=
(0x22e9+ 160-0x2389));(my $__errorTimeout=(0x03e0+ 2366-0x0d1e));sub initialize{
__setTimeBetweenPings ();__setTimeoutForPingResponse ();__sendPing ();}sub 
__setTimeBetweenPings{($__interval=(0x0381+ 5055-0x1722));Logger::debug (((
"\x4e\x58\x50\x69\x6e\x67\x4d\x6f\x6e\x69\x74\x6f\x72\x3a\x20\x54\x69\x6d\x65\x20\x62\x65\x74\x77\x65\x65\x6e\x20\x70\x69\x6e\x67\x73\x20\x74\x6f\x20\x74\x68\x65\x20\x73\x65\x72\x76\x65\x72\x3a\x20"
.$__interval)."\x2e"));}sub __setTimeoutForPingResponse{if ((not ((
$GLOBAL::NodeConnectionTimeout=~ /\d+/ )))){Logger::warning (
"\x4e\x58\x50\x69\x6e\x67\x4d\x6f\x6e\x69\x74\x6f\x72\x3a\x20\x49\x6e\x76\x61\x6c\x69\x64\x20\x76\x61\x6c\x75\x65\x20\x66\x6f\x72\x20\x74\x68\x65\x20\x4e\x6f\x64\x65\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x54\x69\x6d\x65\x6f\x75\x74\x20\x6b\x65\x79\x2e\x20\x55\x73\x69\x6e\x67\x20\x64\x65\x66\x61\x75\x6c\x74\x2e"
);($GLOBAL::NodeConnectionTimeout=(0x00ec+ 1953-0x0815));}($__timeout=
$GLOBAL::NodeConnectionTimeout);Logger::debug (((
"\x4e\x58\x50\x69\x6e\x67\x4d\x6f\x6e\x69\x74\x6f\x72\x3a\x20\x54\x69\x6d\x65\x6f\x75\x74\x20\x66\x6f\x72\x20\x70\x69\x6e\x67\x20\x72\x65\x73\x70\x6f\x6e\x73\x65\x3a\x20"
.$__timeout)."\x2e"));}sub checkTimesAndSendPingIfNecessary{if ((__isPingEnabled
 ()==(0x0192+ 2011-0x096d))){return;}if ((__isTimeoutForPingRespose ()==
(0x1afd+ 1419-0x2087))){if ((__isErrorServerDidNotReply ()==(0x196a+ 877-0x1cd6)
)){Logger::error (((
"\x53\x65\x72\x76\x65\x72\x20\x64\x69\x64\x20\x6e\x6f\x74\x20\x72\x65\x70\x6c\x79\x20\x73\x69\x6e\x63\x65\x20"
.$__timeout).
"\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e\x20\x54\x65\x72\x6d\x69\x6e\x61\x74\x69\x6e\x67\x20\x73\x65\x73\x73\x69\x6f\x6e\x2e"
));NXSessionMonitor::__setSessionStatus ($NXSessionMonitor::statusError,((
"\x4c\x6f\x73\x74\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x74\x6f\x20\x4e\x58\x20\x73\x65\x72\x76\x65\x72\x3a\x20\x6e\x6f\x20\x72\x65\x70\x6c\x69\x65\x73\x20\x69\x6e\x20"
.$__timeout)."\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e"));return;}
__setErrorServerDidNotReply ();Logger::warning (((
"\x53\x65\x72\x76\x65\x72\x20\x64\x69\x64\x20\x6e\x6f\x74\x20\x72\x65\x70\x6c\x79\x20\x73\x69\x6e\x63\x65\x20"
.$__timeout)."\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e"));__sendPing ();return;}if (
(__isPingTime ()==(0x0764+ 757-0x0a58))){__sendPing ();return;}}sub handlePong{
Logger::debug (
"\x52\x65\x63\x65\x69\x76\x65\x64\x20\x70\x6f\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);__clearErrorServerDidNotReply ();__setPongTime ();__resetPingTime ();}sub 
handleRequestForPingMessage{Logger::debug (
"\x52\x65\x63\x65\x69\x76\x65\x64\x20\x72\x65\x71\x75\x65\x73\x74\x20\x66\x6f\x72\x20\x73\x65\x6e\x64\x20\x70\x69\x6e\x67\x20\x74\x6f\x20\x74\x68\x65\x20\x73\x65\x72\x76\x65\x72\x2e"
);__sendPing ();}sub __sendPing{Logger::debug (
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x70\x69\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);(my $message=(((("\x4e\x58\x3e\x20".$GLOBAL::MSG_NODE_PING)."\x20").
$GLOBAL::MESSAGES_FORMAT{$GLOBAL::MSG_NODE_PING})."\x0a"));(my $bytes=
main::nxwrite (main::nxgetSTDOUT (),$message));if (($bytes==(-
(0x197a+ 404-0x1b0d)))){NXSessionMonitor::__setSessionStatus (
$NXSessionMonitor::statusError,
"\x4c\x6f\x73\x74\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x74\x6f\x20\x4e\x58\x20\x73\x65\x72\x76\x65\x72\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x73\x65\x6e\x64\x20\x70\x69\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x20\x74\x6f\x20\x73\x65\x72\x76\x65\x72\x2e"
);return;}__resetPongTime ();__setPingTime ();}sub __isPingEnabled{if ((
$__timeout==(0x034f+ 6333-0x1c0c))){return ((0x04f2+ 2731-0x0f9d));}return (
(0x1b58+ 761-0x1e50));}sub __setPingTime{($__pingTime=
Common::NXTime::getSecondsSinceEpoch ());}sub __resetPingTime{($__pingTime=
(0x1965+ 1118-0x1dc3));}sub __isPingTime{if (($__pongTime==(0x0d3d+ 1542-0x1343)
)){return ((0x0776+ 4879-0x1a85));}(my $time=
Common::NXTime::getSecondsSinceEpoch ());if (($time>=($__pongTime+$__interval)))
{return ((0x0f32+ 5265-0x23c2));}return ((0x060b+ 8083-0x259e));}sub 
__isTimeoutForPingRespose{if (($__pingTime==(0x105f+ 5296-0x250f))){return (
(0x164f+ 834-0x1991));}(my $time=Common::NXTime::getSecondsSinceEpoch ());if ((
$__pingTime>$time)){($__pingTime=Common::NXTime::getSecondsSinceEpoch ());}if ((
$time>=($__pingTime+$__timeout))){return ((0x1ca1+ 1086-0x20de));}return (
(0x0722+ 1511-0x0d09));}sub __setErrorServerDidNotReply{($__errorTimeout=
(0x1057+ 2351-0x1985));}sub __isErrorServerDidNotReply{return ($__errorTimeout);
}sub __clearErrorServerDidNotReply{($__errorTimeout=(0x2215+ 206-0x22e3));}sub 
__setPongTime{($__pongTime=Common::NXTime::getSecondsSinceEpoch ());}sub 
__resetPongTime{($__pongTime=(0x06b6+ 3163-0x1311));}return (
(0x0ab1+ 5535-0x204f));

==> nomachine-8.6.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXPingMonitor.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXPingMonitor;no warnings;(my $__pingTime=(0x1780+ 485-0x1965));(my $__pongTime
=(0x0556+ 8429-0x2643));(my $__interval=(0x1522+ 522-0x172c));(my $__timeout=
(0x06a1+ 4870-0x19a7));(my $__errorTimeout=(0x0da5+ 2449-0x1736));sub initialize
{__setTimeBetweenPings ();__setTimeoutForPingResponse ();__sendPing ();}sub 
__setTimeBetweenPings{($__interval=(0x0341+ 830-0x0661));Logger::debug (((
"\x4e\x58\x50\x69\x6e\x67\x4d\x6f\x6e\x69\x74\x6f\x72\x3a\x20\x54\x69\x6d\x65\x20\x62\x65\x74\x77\x65\x65\x6e\x20\x70\x69\x6e\x67\x73\x20\x74\x6f\x20\x74\x68\x65\x20\x73\x65\x72\x76\x65\x72\x3a\x20"
.$__interval)."\x2e"));}sub __setTimeoutForPingResponse{if ((not ((
$GLOBAL::NodeConnectionTimeout=~ /\d+/ )))){Logger::warning (
"\x4e\x58\x50\x69\x6e\x67\x4d\x6f\x6e\x69\x74\x6f\x72\x3a\x20\x49\x6e\x76\x61\x6c\x69\x64\x20\x76\x61\x6c\x75\x65\x20\x66\x6f\x72\x20\x74\x68\x65\x20\x4e\x6f\x64\x65\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x54\x69\x6d\x65\x6f\x75\x74\x20\x6b\x65\x79\x2e\x20\x55\x73\x69\x6e\x67\x20\x64\x65\x66\x61\x75\x6c\x74\x2e"
);($GLOBAL::NodeConnectionTimeout=(0x01f5+ 7522-0x1edf));}($__timeout=
$GLOBAL::NodeConnectionTimeout);Logger::debug (((
"\x4e\x58\x50\x69\x6e\x67\x4d\x6f\x6e\x69\x74\x6f\x72\x3a\x20\x54\x69\x6d\x65\x6f\x75\x74\x20\x66\x6f\x72\x20\x70\x69\x6e\x67\x20\x72\x65\x73\x70\x6f\x6e\x73\x65\x3a\x20"
.$__timeout)."\x2e"));}sub checkTimesAndSendPingIfNecessary{if ((__isPingEnabled
 ()==(0x0f42+ 5505-0x24c3))){return;}if ((__isTimeoutForPingRespose ()==
(0x1c52+ 2449-0x25e2))){if ((__isErrorServerDidNotReply ()==
(0x09d8+ 6135-0x21ce))){Logger::error (((
"\x53\x65\x72\x76\x65\x72\x20\x64\x69\x64\x20\x6e\x6f\x74\x20\x72\x65\x70\x6c\x79\x20\x73\x69\x6e\x63\x65\x20"
.$__timeout).
"\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e\x20\x54\x65\x72\x6d\x69\x6e\x61\x74\x69\x6e\x67\x20\x73\x65\x73\x73\x69\x6f\x6e\x2e"
));NXSessionMonitor::__setSessionStatus ($NXSessionMonitor::statusError,((
"\x4c\x6f\x73\x74\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x74\x6f\x20\x4e\x58\x20\x73\x65\x72\x76\x65\x72\x3a\x20\x6e\x6f\x20\x72\x65\x70\x6c\x69\x65\x73\x20\x69\x6e\x20"
.$__timeout)."\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e"));return;}
__setErrorServerDidNotReply ();Logger::warning (((
"\x53\x65\x72\x76\x65\x72\x20\x64\x69\x64\x20\x6e\x6f\x74\x20\x72\x65\x70\x6c\x79\x20\x73\x69\x6e\x63\x65\x20"
.$__timeout)."\x20\x73\x65\x63\x6f\x6e\x64\x73\x2e"));__sendPing ();return;}if (
(__isPingTime ()==(0x090f+ 7200-0x252e))){__sendPing ();return;}}sub handlePong{
Logger::debug (
"\x52\x65\x63\x65\x69\x76\x65\x64\x20\x70\x6f\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);__clearErrorServerDidNotReply ();__setPongTime ();__resetPingTime ();}sub 
handleRequestForPingMessage{Logger::debug (
"\x52\x65\x63\x65\x69\x76\x65\x64\x20\x72\x65\x71\x75\x65\x73\x74\x20\x66\x6f\x72\x20\x73\x65\x6e\x64\x20\x70\x69\x6e\x67\x20\x74\x6f\x20\x74\x68\x65\x20\x73\x65\x72\x76\x65\x72\x2e"
);__sendPing ();}sub __sendPing{Logger::debug (
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x70\x69\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x2e"
);(my $message=(((("\x4e\x58\x3e\x20".$GLOBAL::MSG_NODE_PING)."\x20").
$GLOBAL::MESSAGES_FORMAT{$GLOBAL::MSG_NODE_PING})."\x0a"));(my $bytes=
main::nxwrite (main::nxgetSTDOUT (),$message));if (($bytes==(-
(0x04d3+ 1317-0x09f7)))){NXSessionMonitor::__setSessionStatus (
$NXSessionMonitor::statusError,
"\x4c\x6f\x73\x74\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x74\x6f\x20\x4e\x58\x20\x73\x65\x72\x76\x65\x72\x2e\x20\x43\x61\x6e\x6e\x6f\x74\x20\x73\x65\x6e\x64\x20\x70\x69\x6e\x67\x20\x6d\x65\x73\x73\x61\x67\x65\x20\x74\x6f\x20\x73\x65\x72\x76\x65\x72\x2e"
);return;}__resetPongTime ();__setPingTime ();}sub __isPingEnabled{if ((
$__timeout==(0x048c+ 1563-0x0aa7))){return ((0x027b+ 9015-0x25b2));}return (
(0x091d+ 2170-0x1196));}sub __setPingTime{($__pingTime=
Common::NXTime::getSecondsSinceEpoch ());}sub __resetPingTime{($__pingTime=
(0x073c+ 3273-0x1405));}sub __isPingTime{if (($__pongTime==(0x0036+ 9324-0x24a2)
)){return ((0x0823+ 3796-0x16f7));}(my $time=
Common::NXTime::getSecondsSinceEpoch ());if (($time>=($__pongTime+$__interval)))
{return ((0x0d4f+ 3353-0x1a67));}return ((0x10fd+ 4353-0x21fe));}sub 
__isTimeoutForPingRespose{if (($__pingTime==(0x1ab0+ 2558-0x24ae))){return (
(0x0d8d+ 2601-0x17b6));}(my $time=Common::NXTime::getSecondsSinceEpoch ());if ((
$__pingTime>$time)){($__pingTime=Common::NXTime::getSecondsSinceEpoch ());}if ((
$time>=($__pingTime+$__timeout))){return ((0x04ff+ 5590-0x1ad4));}return (
(0x0edc+ 2194-0x176e));}sub __setErrorServerDidNotReply{($__errorTimeout=
(0x1655+ 4168-0x269c));}sub __isErrorServerDidNotReply{return ($__errorTimeout);
}sub __clearErrorServerDidNotReply{($__errorTimeout=(0x0087+ 7862-0x1f3d));}sub 
__setPongTime{($__pongTime=Common::NXTime::getSecondsSinceEpoch ());}sub 
__resetPongTime{($__pongTime=(0x00a0+ 3046-0x0c86));}return (
(0x1d0b+ 1041-0x211b));
